# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global section		devel
%global upstreamrel	1210
%global upstreammajor	9.4
%global source_path	pgjdbc/src/main/java/org/postgresql
%global parent_ver	1.1.1
%global parent_poms_builddir	./pgjdbc-parent-poms

%global pgjdbc_mvn_options -DwaffleEnabled=false -DosgiEnabled=false \\\
	-DexcludePackageNames=org.postgresql.osgi:org.postgresql.sspi

Summary:	JDBC driver for PostgreSQL
Name:		postgresql-jdbc
Version:	%{upstreammajor}.%{upstreamrel}
Release:	%mkrel 1
# ASL 2.0 applies only to postgresql-jdbc.pom file, the rest is BSD
License:	BSD and ASL 2.0
Group:		Development/Java
URL:		http://jdbc.postgresql.org/

Source0:	https://github.com/pgjdbc/pgjdbc/archive/REL%{version}.tar.gz

# Upstream moved parent pom.xml into separate project (even though there is only
# one dependant project on it?).  Let's try to not complicate packaging by
# having separate spec file for it, too.
Source2: https://github.com/pgjdbc/pgjdbc-parent-poms/archive/REL%{parent_ver}.tar.gz

BuildArch:	noarch
BuildRequires:	java-devel >= 1.8
BuildRequires:	maven-local
BuildRequires:	java-comment-preprocessor
BuildRequires:	properties-maven-plugin
BuildRequires:	maven-enforcer-plugin
BuildRequires:	maven-plugin-bundle
BuildRequires:	maven-plugin-build-helper

# gettext is only needed if we try to update translations
#BuildRequires:	  gettext

%description
PostgreSQL is an advanced Object-Relational database management
system. The postgresql-jdbc package includes the .jar files needed for
Java programs to access a PostgreSQL database.

%package     parent-poms
Summary:     Build dependency management for PostgreSQL JDBC driver

%description parent-poms
Pom files bringing dependencies required for successful PostgreSQL JDBC driver
build.

%package javadoc
Summary:	API docs for %{name}
Group:		Documentation

%description javadoc
This package contains the API Documentation for %{name}.

%prep
%setup -c -q -a 2 -n pgjdbc-REL%version

mv pgjdbc-REL%version/* .
mv pgjdbc-parent-poms-REL%parent_ver pgjdbc-parent-poms

# remove any binary libs
find -name "*.jar" -or -name "*.class" | xargs rm -f

%pom_disable_module ubenchmark

# Build parent POMs in the same Maven call.
%pom_xpath_inject pom:modules "<module>%parent_poms_builddir</module>"
%pom_xpath_inject pom:parent "<relativePath>pgjdbc-parent-poms/pgjdbc-versions</relativePath>"
%pom_xpath_set pom:relativePath ../pgjdbc-parent-poms/pgjdbc-core-parent pgjdbc

# compat symlink: requested by dtardon (libreoffice), reverts part of
# 0af97ce32de877 commit.
%mvn_file org.postgresql:postgresql %{name}/postgresql %{name}

# Parent POMs should be installed in a separate subpackage.
%mvn_package ":*{parent,versions,prevjre}*" parent-poms

# For compat reasons, make Maven artifact available under older coordinates.
%mvn_alias org.postgresql:postgresql postgresql:postgresql

# Hack #1!  This directory is missing for some reason, it is most probably some
# misunderstanding between maven, maven-compiler-plugin and
# java-comment-preprocessor?  Not solved yet.  See rhbz#1325060.
mkdir -p pgjdbc/target/generated-sources/annotations


%build
# Ideally we would run "sh update-translations.sh" here, but that results
# in inserting the build timestamp into the generated messages_*.class
# files, which makes rpmdiff complain about multilib conflicts if the
# different platforms don't build in the same minute.  For now, rely on
# upstream to have updated the translations files before packaging.

%mvn_build -f -- %pgjdbc_mvn_options


%install
%mvn_install


%files -f .mfiles
%license LICENSE
%doc README.md


%files parent-poms -f .mfiles-parent-poms
%license LICENSE
%doc pgjdbc-parent-poms/CHANGELOG.md pgjdbc-parent-poms/README.md


%files javadoc -f .mfiles-javadoc
%license LICENSE


%changelog
* Wed Sep 14 2016 luigiwalser <luigiwalser> 9.4.1210-1.mga6
+ Revision: 1052560
- 9.4.1210 (sync with fedora 25)

* Fri Aug 12 2016 luigiwalser <luigiwalser> 9.4.1209-2.mga6
+ Revision: 1046089
- 9.4.1209 (sync with fedora 25)

  + neoclust <neoclust>
    - Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 9.4.1200-4.mga6
+ Revision: 977761
- First rebuild of the java stack
- sync package postgresql-jdbc with fedora

* Tue Feb 09 2016 umeabot <umeabot> 9.4.1200-2.mga6
+ Revision: 952291
- Mageia 6 Mass Rebuild

* Fri Feb 13 2015 luigiwalser <luigiwalser> 9.4.1200-1.mga5
+ Revision: 814848
- 9.4.1200 (sync with f22)

* Fri Dec 26 2014 dmorgan <dmorgan> 9.3.1102-6.mga5
+ Revision: 806238
- Sync with fc21

* Sat Nov 08 2014 cjw <cjw> 0:9.3.1102-5.mga5
+ Revision: 796065
- remove the maven-metadata xml file because it breaks the build

  + tv <tv>
    - adjust file list
    - Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 0:9.3.1102-4.mga5
+ Revision: 741572
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:9.3.1102-3.mga5
+ Revision: 687735
- Mageia 5 Mass Rebuild

* Wed Aug 27 2014 tv <tv> 0:9.3.1102-2.mga5
+ Revision: 668640
- requires java-headless instead of java-headless (so that LO pull less

* Fri Jul 18 2014 luigiwalser <luigiwalser> 0:9.3.1102-1.mga5
+ Revision: 653558
- 9.3.1102
- add patch from fedora to fix build

* Sun Apr 27 2014 luigiwalser <luigiwalser> 0:9.3.1101-1.mga5
+ Revision: 618341
- 9.3.1101

* Fri Nov 08 2013 dmorgan <dmorgan> 0:9.2.1002-6.mga4
+ Revision: 550000
- Remove useless macros

* Sat Oct 19 2013 umeabot <umeabot> 0:9.2.1002-5.mga4
+ Revision: 531318
- Mageia 4 Mass Rebuild

* Sat Aug 03 2013 joequant <joequant> 0:9.2.1002-4.mga4
+ Revision: 462958
- remove ant-nodeps and ant-trax

* Sun Apr 14 2013 dmorgan <dmorgan> 0:9.2.1002-3.mga3
+ Revision: 410103
- Add require on jpackage-utils ( mga#9645)

* Fri Feb 08 2013 fwang <fwang> 0:9.2.1002-2.mga3
+ Revision: 395328
- cleanup spec

* Fri Feb 08 2013 fwang <fwang> 0:9.2.1002-1.mga3
+ Revision: 395322
- new version 9.2-1002

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 12 2011 dmorgan <dmorgan> 0:9.0.801-1.mga2
+ Revision: 132810
- Clean spec file

  + gil <gil>
    - update to 9.0-801

* Fri Jan 28 2011 dmorgan <dmorgan> 0:8.3.603-2.0.2.mga1
+ Revision: 43103
- imported package postgresql-jdbc

